@@ -299,7 +299,7 @@ class RectangleShape(Shape):
         width, height = self.GetModel().GetSize()
 
         #  get the diagram frame ratio between the shape and the model
-        ratio = self.GetDiagram().GetPanel().GetCurrentZoom()
+        ratio = self.GetDiagram().GetPanel().currentZoom
 
         # set the new size to the shape.
         self._width  = round(width * ratio)
@@ -317,7 +317,7 @@ class RectangleShape(Shape):
 
         # get the ratio between the model and the shape (view) from
         # the diagram frame where the shape is displayed.
-        ratio = self.GetDiagram().GetPanel().GetCurrentZoom()
+        ratio = self.GetDiagram().GetPanel().currentZoom
 
         # set the new size to the model.
         self.GetModel().SetSize(round(width//ratio), round(height//ratio))
