@@ -39,16 +39,22 @@ class OglPreferences(Singleton):
     TEXT_ITALICIZE:   str = 'text_italicize'
     TEXT_FONT_FAMILY: str = 'text_font_family'
     TEXT_FONT_SIZE:   str = 'text_font_size'
+    TEXT_VALUE:       str = 'text_value'
     CLASS_NAME:       str = 'class_name'
     CLASS_DIMENSIONS: str = 'class_dimensions'
+    CLASS_BACKGROUND_COLOR: str = 'class_background_color'
+    CLASS_TEXT_COLOR:       str = 'class_text_color'
 
     DEFAULT_NAME_INTERFACE: str = 'default_name_interface'
     DEFAULT_NAME_USECASE:   str = 'default_name_usecase'
     DEFAULT_NAME_ACTOR:     str = 'default_name_actor'
     DEFAULT_NAME_METHOD:    str = 'default_name_method'
+    DEFAULT_CLASS_BACKGROUND_COLOR: str = MiniOglColorEnum.LIGHT_GREY.value
+    DEFAULT_CLASS_TEXT_COLOR:       str = MiniOglColorEnum.WHITE.value
 
     SHOW_PARAMETERS:            str = 'Show_Parameters'
 
+    # noinspection SpellCheckingInspection
     OGL_PREFERENCES: OGL_PREFS_NAME_VALUES = {
         NOTE_TEXT:              'This is the note text',
         NOTE_DIMENSIONS:        OglDimensions(100, 50).__str__(),
@@ -57,8 +63,11 @@ class OglPreferences(Singleton):
         TEXT_ITALICIZE:         'False',
         TEXT_FONT_FAMILY:       'Swiss',
         TEXT_FONT_SIZE:         '14',
+        TEXT_VALUE:             'Donec eleifend luctus enim vel mollis',
         CLASS_NAME:             'ClassName',
         CLASS_DIMENSIONS:        OglDimensions(100, 100).__str__(),
+        CLASS_BACKGROUND_COLOR:  DEFAULT_CLASS_BACKGROUND_COLOR,
+        CLASS_TEXT_COLOR:        DEFAULT_CLASS_TEXT_COLOR,
         DEFAULT_NAME_INTERFACE: 'IClassInterface',
         DEFAULT_NAME_USECASE:   'UseCaseName',
         DEFAULT_NAME_ACTOR:     'ActorName',
@@ -93,6 +102,7 @@ class OglPreferences(Singleton):
         DEBUG_BASIC_SHAPE:   'False',
     }
 
+    # noinspection PyAttributeOutsideInit
     def init(self, *args, **kwargs):
 
         self.logger:  Logger       = getLogger(__name__)
@@ -187,6 +197,15 @@ class OglPreferences(Singleton):
         self._config.set(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.TEXT_FONT_SIZE, str(newValue))
         self.__saveConfig()
 
+    @property
+    def textValue(self) -> str:
+        return self._config.get(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.TEXT_VALUE)
+
+    @textValue.setter
+    def textValue(self, newValue: str):
+        self._config.set(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.TEXT_VALUE, newValue)
+        self.__saveConfig()
+
     @property
     def className(self) -> str:
         return self._config.get(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.CLASS_NAME)
@@ -206,6 +225,31 @@ class OglPreferences(Singleton):
         self._config.set(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.CLASS_DIMENSIONS, newValue.__str__())
         self.__saveConfig()
 
+    @property
+    def classBackgroundColor(self) -> MiniOglColorEnum:
+        colorName:     str           = self._config.get(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.CLASS_BACKGROUND_COLOR)
+        pyutColorEnum: MiniOglColorEnum = MiniOglColorEnum(colorName)
+        return pyutColorEnum
+
+    @classBackgroundColor.setter
+    def classBackgroundColor(self, newValue: MiniOglColorEnum):
+        colorName: str = newValue.value
+        self._config.set(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.CLASS_BACKGROUND_COLOR, colorName)
+        self.__saveConfig()
+
+    @property
+    def classTextColor(self) -> MiniOglColorEnum:
+        colorName:     str           = self._config.get(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.CLASS_TEXT_COLOR)
+        pyutColorEnum: MiniOglColorEnum = MiniOglColorEnum(colorName)
+        return pyutColorEnum
+
+    @classTextColor.setter
+    def classTextColor(self, newValue: MiniOglColorEnum):
+        colorName: str = newValue.value
+        self._config.set(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.CLASS_TEXT_COLOR, colorName)
+
+        self.__saveConfig()
+
     @property
     def interfaceName(self) -> str:
         return self._config.get(OglPreferences.OGL_PREFERENCES_SECTION, OglPreferences.DEFAULT_NAME_INTERFACE)
